.center { 
  text-align: center;
}

.center table { 
  margin-left: auto;
  margin-right: auto;
  text-align: center;
}

body {
  font-family: verdana, sans-serif;
  color: #555555;
  background-color: white;
}

a:link, a:visited {
  color: #001dd9; text-decoration: none;
  background: transparent;
}

a:hover { 
  color: #00ffd8; 
  text-decoration: none;
}

.small {
  font-size: 75%;
}

.large {
  font-size: 200%;
}

.tiled {
  background-image: url(".tile.png");
  background-repeat: repeat-x;
  background-color: black;
  padding: 0;
}

.thumb {
  background-color: black;
  text-align: center;
  vertical-align: middle;
}

.slide {
  background-color: white;
  text-align: center;
  vertical-align: middle;
}

#exifinfo { display: none; padding-top: 5px;}
#exifinfo > table, #exifinfo td {  border-collapse: collapse; border: 1px solid; }
